# PySpreader
### The Python reference package client for the Spreader distributed work system.

This repository holds the most up to date version of the Python client to use the (Spreader distributed work system)[https://github.com/LukeCroteau/spreader].

This project is distributed via PyPI.
